@@ -30,7 +30,7 @@
 
 namespace pyedt {
 
-#define sq(x) ((x) * (x))
+#define sq(x) (static_cast<float>(x) * static_cast<float>(x))
 
 inline void tofinite(float *f, const size_t voxels) {
   for (size_t i = 0; i < voxels; i++) {
@@ -362,7 +362,7 @@ void squared_edt_1d_parabolic_multi_seg(
           f + last * stride, 
           d + last * stride, 
           i - last, stride, anisotropy,
-          (black_border || last > 0), (i < n - 1) 
+          (black_border || last > 0), true
         );
       }
       working_segid = segid;
@@ -962,7 +962,7 @@ float* binary_edtsq(
 
 } // namespace edt
 
-
+#undef sq
 
 #endif
 
